# notedata

数据管理


|序号|分类|名称|描述|
|:-:|:-:|:-:|:-:|
|0|dataset|iris|iris数据集|
|1|dataset|electronics-reviews||
|2|dataset|electronics-meta||
|3|dataset|movielens-100k||
|4|dataset|movielens-1m||
|5|dataset|movielens-10m||
|6|dataset|movielens-20m||
|7|dataset|movielens-25m||
|8|dataset|adult-train||
|9|dataset|adult-test||
|10|dataset|porto-seguro-train||
|11|dataset|porto-seguro-test||
|12|dataset|bitly-usagov||
|13|dataset|coco-val2017||
|14|dataset|coco-annotations_trainval2017||
|15|yolov3模型的权重|yolov3.weight||
|16|yolov4模型的权重|yolov4.weight||

